pub struct ChainStateViewReadGuard<S: Storage>(/* private fields */);Expand description
A read guard providing access to a chain’s ChainStateView.
Holds a read lock on the chain worker state, preventing writes for its
lifetime. The OwnedRwLockReadGuard internally holds a strong Arc
reference to the RwLock<ChainWorkerState>, keeping the state alive.
Dereferences to ChainStateView.
Methods from Deref<Target = ChainStateView<S::Context>>
pub async fn execution_state( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&ExecutionStateView<C>, Error>
pub async fn execution_state_hash( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&RegisterView<C, Option<CryptoHash>>, Error>
pub async fn tip_state( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&RegisterView<C, ChainTipState>, Error>
pub async fn manager( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&ChainManager<C>, Error>
pub async fn pending_validated_blobs( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&PendingBlobsView<C>, Error>
pub async fn pending_proposed_blobs( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&ReentrantCollectionView<C, AccountOwner, PendingBlobsView<C>>, Error>
pub async fn confirmed_log( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&LogView<C, CryptoHash>, Error>
pub async fn received_log( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&LogView<C, ChainAndHeight>, Error>
pub async fn received_certificate_trackers( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&RegisterView<C, HashMap<Secp256k1PublicKey, u64>>, Error>
pub async fn inboxes( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&ReentrantCollectionView<C, ChainId, InboxStateView<C>>, Error>
pub async fn outboxes( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&ReentrantCollectionView<C, ChainId, OutboxStateView<C>>, Error>
pub async fn next_expected_events( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&MapView<C, StreamId, u32>, Error>
pub async fn outbox_counters( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&RegisterView<C, BTreeMap<BlockHeight, u32>>, Error>
pub async fn nonempty_outboxes( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&RegisterView<C, BTreeSet<ChainId>>, Error>
pub async fn preprocessed_blocks( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&MapView<C, BlockHeight, CryptoHash>, Error>
pub async fn nonempty_inboxes( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&RegisterView<C, BTreeSet<ChainId>>, Error>
Sourcepub fn chain_id(&self) -> ChainId
pub fn chain_id(&self) -> ChainId
Returns the ChainId of the chain this ChainStateView represents.
Sourcepub fn all_messages_delivered_up_to(&self, height: BlockHeight) -> bool
pub fn all_messages_delivered_up_to(&self, height: BlockHeight) -> bool
Returns true if there are no more outgoing messages in flight up to the given block height.
Sourcepub async fn inbox_cursors(
&self,
origin: &ChainId,
) -> Result<(BlockHeight, Option<BlockHeight>), ChainError>
pub async fn inbox_cursors( &self, origin: &ChainId, ) -> Result<(BlockHeight, Option<BlockHeight>), ChainError>
Returns the next block height to receive and the last anticipated block height for the given origin, loading the inbox read-only.
Sourcepub async fn next_height_to_preprocess(&self) -> Result<BlockHeight, ChainError>
pub async fn next_height_to_preprocess(&self) -> Result<BlockHeight, ChainError>
Returns the height of the highest block we have, plus one. Includes preprocessed blocks.
The “+ 1” is so that it can be used in the same places as next_block_height.
pub fn current_committee(&self) -> Result<(Epoch, &Committee), ChainError>
pub fn ownership(&self) -> &ChainOwnership
Sourcepub fn nonempty_outbox_chain_ids(&self) -> Vec<ChainId>
pub fn nonempty_outbox_chain_ids(&self) -> Vec<ChainId>
Returns the chain IDs of all recipients for which a message is waiting in the outbox.
Sourcepub async fn load_outboxes(
&self,
targets: &[ChainId],
) -> Result<Vec<ReadGuardedView<OutboxStateView<C>>>, ChainError>
pub async fn load_outboxes( &self, targets: &[ChainId], ) -> Result<Vec<ReadGuardedView<OutboxStateView<C>>>, ChainError>
Returns the outboxes for the given targets, or an error if any of them are missing.
Sourcepub async fn block_hashes(
&self,
heights: impl IntoIterator<Item = BlockHeight>,
) -> Result<Vec<CryptoHash>, ChainError>
pub async fn block_hashes( &self, heights: impl IntoIterator<Item = BlockHeight>, ) -> Result<Vec<CryptoHash>, ChainError>
Returns the hashes of all blocks we have in the given range.
If the input heights are in ascending order, the hashes will be in the same order. Otherwise they may be unordered.